@@ -1,5 +1,5 @@
 import json
-from typing import Optional
+from typing import Dict, Optional, Union
 
 import requests  # type: ignore
 import yaml  # type: ignore
@@ -21,8 +21,8 @@ class JpsClient(BaseClient):
         env_name: Optional[str] = None,
         settings: Optional[dict] = None,
         region: Optional[str] = None,
-        success: Optional[dict] = None,
-    ) -> str:
+        env_props_query: Optional[dict] = None,
+    ) -> Union[str, Dict[str, str]]:
         try:
             file = open(filename, "r")
         except OSError:
@@ -31,7 +31,11 @@ class JpsClient(BaseClient):
         with file:
             manifest_content = file.read()
             return self.install(
-                manifest_content, env_name, settings, region=region, success=success
+                manifest_content,
+                env_name,
+                settings,
+                region=region,
+                env_props_query=env_props_query,
             )
 
     def install_from_url(
@@ -40,24 +44,31 @@ class JpsClient(BaseClient):
         env_name: Optional[str] = None,
         settings: Optional[dict] = None,
         region: Optional[str] = None,
-        success: Optional[dict] = None,
-    ) -> str:
+        env_props_query: Optional[dict] = None,
+    ) -> Union[str, Dict[str, str]]:
         response = requests.get(url)
         if response.status_code != 200:
             raise JelasticClientException(f"Url not found: {url}")
         manifest_content = response.text
         return self.install(
-            manifest_content, env_name, settings, region=region, success=success
+            manifest_content,
+            env_name,
+            settings,
+            region=region,
+            env_props_query=env_props_query,
         )
 
+    # TODO: add the following arguments:
+    # - send_node_emails: bool
+    # - send_success_email: bool
     def install(
         self,
         manifest_content: str,
         env_name: Optional[str] = None,
         settings: Optional[dict] = None,
         region: Optional[str] = None,
-        success: Optional[dict] = None,
-    ) -> str:
+        env_props_query: Optional[dict] = None,
+    ) -> Union[str, Dict[str, str]]:
         """
         Install a custom JPS manifest.
 
@@ -67,12 +78,14 @@ class JpsClient(BaseClient):
         :param settings: the manifest settings
         :param region: the region where to install the manifest
                        (supported by the Jelastic provider)
-        :param success: replacement for the success section in the input manifest
-        :return: manifest success text
+        :param env_props_query: set of (key, value) to query an installation about
+            e.g. ("AdminPassword", "${nodes.sqldb.password}")
+        :return: manifest success text if no env_props_query was provided,
+                 else the set of (key, value) corresponding to the env_props_query
         """
-        if success:
-            manifest_content = self._replace_success_in_manifest(
-                manifest_content, success
+        if env_props_query:
+            manifest_content = self._apply_env_props_query(
+                manifest_content, env_props_query
             )
 
         response = self._execute(
@@ -84,16 +97,33 @@ class JpsClient(BaseClient):
             region=region,
         )
 
-        return response["successText"]
+        return (
+            self._get_env_props(response["successText"])
+            if env_props_query
+            else response["successText"]
+        )
 
+    # TODO: the separator ", " should be somehow stored somewhere
     @staticmethod
-    def _replace_success_in_manifest(manifest_content: str, success: dict) -> str:
+    def _apply_env_props_query(
+        manifest_content: str, env_props_query: Dict[str, str]
+    ) -> str:
         manifest_data = yaml.safe_load(manifest_content)
-        manifest_data["success"] = success
+        manifest_data["success"] = {
+            "email": False,
+            "text": ", ".join(
+                f"{key}: {value}" for key, value in env_props_query.items()
+            ),
+        }
         updated_manifest_content = yaml.dump(manifest_data)
         return updated_manifest_content
 
+    # TODO: the separator ", " should be somehow stored somewhere
+    @staticmethod
+    def _get_env_props(response: str) -> Dict[str, str]:
+        items = response.split(", ")
+        return {item.split(": ")[0]: item.split(": ")[1] for item in items}
+
     def get_engine_version(self) -> str:
         response = self._execute(who_am_i())
-
         return response["version"]
